Moment class

Constructors

Moment([Object? dateTime])
Moment.utc([Object? dateTime])

Properties

dateTime DateTime
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Object? value, [String? unit]) Moment
difference(Object? dateTime) Duration
format([String? format]) String
isAfter(Object? dateTime) bool
isBefore(Object? dateTime) bool
isBetween(Object? startTime, Object? endTime) bool
isSame(Object? dateTime, String unit) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subtract(Object? value, [String? unit]) Moment
toDate() DateTime
toLocal() Moment
toString() String
A string representation of this object.
inherited
toUtc() Moment
tz(String locationName, [dynamic force = false]) Moment
unix() int

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

duration(Duration duration, String format) String
initializeTimeZones() → dynamic